---
name: Usage question
about: Get help solving a problem with Chaospy
title: ''
labels: question
assignees: ''

---

**Describe your problem**
A short description of the problem you are trying to solve.

**Initial implementation**
Assuming you have already made an effort to solve to problem on your own,
please provide a minimal code example.

**Additional context**
Add any other context about the feature request here.
